# Generated by Django 4.2.23 on 2025-09-25 15:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("nemo_mqtt", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="mqttconfiguration",
            name="ca_cert_content",
            field=models.TextField(
                blank=True, help_text="CA certificate content (PEM format)", null=True
            ),
        ),
        migrations.AddField(
            model_name="mqttconfiguration",
            name="client_cert_content",
            field=models.TextField(
                blank=True,
                help_text="Client certificate content (PEM format)",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="mqttconfiguration",
            name="client_key_content",
            field=models.TextField(
                blank=True,
                help_text="Client private key content (PEM format)",
                null=True,
            ),
        ),
    ]
